@@ -9,12 +9,13 @@ use std::path::PathBuf;
 #[derive(Debug, Parser)]
 #[clap(version)]
 struct Args {
-    path: Option<PathBuf>,
+    #[clap(default_value = "-")]
+    path: PathBuf,
 }
 
 #[derive(Clone, Debug, serde::Deserialize)]
 #[serde(tag = "reason", rename_all = "kebab-case")]
-enum ClippyObj {
+enum CargoMessage {
     CompilerArtifact(json::Value),
     BuildScriptExecuted(json::Value),
     CompilerMessage { message: CompilerMessage },
@@ -43,22 +44,11 @@ struct CompilerMessageSpan {
 fn main() -> Result<()> {
     let Args { path } = Args::parse();
 
-    let objs = if let Some(p) = path {
-        let f = std::fs::File::open(p)?;
-        json::Deserializer::from_reader(f)
-            .into_iter::<ClippyObj>()
-            .collect::<Result<Vec<_>, _>>()?
-    } else {
-        json::Deserializer::from_reader(std::io::stdin())
-            .into_iter::<ClippyObj>()
-            .collect::<Result<Vec<_>, _>>()?
-    };
-
-    for res in objs {
-        match res {
-            ClippyObj::CompilerArtifact(_) => {}
-            ClippyObj::BuildScriptExecuted(_) => {}
-            ClippyObj::CompilerMessage { message } => {
+    for msg in read_messages(path)? {
+        match msg {
+            CargoMessage::CompilerArtifact(_) => {}
+            CargoMessage::BuildScriptExecuted(_) => {}
+            CargoMessage::CompilerMessage { message } => {
                 if message.code.is_some() {
                     let msg = encode_newlines(message.rendered);
                     for span in message.spans.into_iter() {
@@ -75,9 +65,9 @@ fn main() -> Result<()> {
                     }
                 }
             }
-            ClippyObj::BuildFinished { success } => {
+            CargoMessage::BuildFinished { success } => {
                 if !success {
-                    anyhow::bail!("command failed")
+                    anyhow::bail!("build failed")
                 }
             }
         }
@@ -86,6 +76,21 @@ fn main() -> Result<()> {
     Ok(())
 }
 
+fn read_messages(path: PathBuf) -> Result<Vec<CargoMessage>> {
+    if path.to_str() == Some("-") {
+        let msgs = json::Deserializer::from_reader(std::io::stdin())
+            .into_iter::<CargoMessage>()
+            .collect::<Result<Vec<_>, _>>()?;
+        return Ok(msgs);
+    }
+
+    let f = std::fs::File::open(path)?;
+    let msgs = json::Deserializer::from_reader(f)
+        .into_iter::<CargoMessage>()
+        .collect::<Result<Vec<_>, _>>()?;
+    Ok(msgs)
+}
+
 fn encode_newlines(orig: String) -> String {
     orig.replace('\n', "%0A")
 }
